@@ -489,6 +489,19 @@ visit_guest (guestfs_h *g)
   return t;
 }
 
+/* In visit_entry, GCC 14 falsely reports:
+ *
+ * diff.c: In function ‘visit_entry’:
+ * diff.c:565:16: error: pointer ‘old_files_95’ may be used after ‘realloc’ [-Werror=use-after-free]
+ *   565 |       t->files = old_files;
+ *       |       ~~~~~~~~~^~~~~~~~~~~
+ * diff.c:562:16: note: call to ‘realloc’ here
+ *   562 |     t->files = realloc (old_files, t->allocated * sizeof (struct file));
+ *       |                ^~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+ */
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Wuse-after-free"
+
 /* Visit each directory/file/etc entry in the tree.  This just stores
  * the data in the tree.  Note we don't store file content, but we
  * keep the guestfs handle open so we can pull that out later if we
@@ -583,6 +596,8 @@ visit_entry (const char *dir, const char *name,
   return -1;
 }
 
+#pragma GCC diagnostic pop
+
 static void deleted (guestfs_h *, struct file *);
 static void added (guestfs_h *, struct file *);
 static int compare_stats (struct file *, struct file *);
@@ -717,8 +732,20 @@ changed (guestfs_h *g1, struct file *file1,
     output_string ("changed:");
 #define COMPARE_STAT(n)						\
     if (file1->stat->n != file2->stat->n) output_string (#n)
-    COMPARE_STAT (st_dev);
-    COMPARE_STAT (st_ino);
+    /* Comparing st_dev and st_ino is disabled for now, see the longer
+     * discussion here:
+     * https://listman.redhat.com/archives/libguestfs/2023-July/032061.html
+     * Even if we fixed the libguestfs API to do translation of this
+     * field correctly, it seems unlikely that there would ever be a
+     * meaningful difference in the st_dev or st_ino fields.  We
+     * already know the fields refer to the same filename.  Is it
+     * interesting that the file might have moved to a different disk?
+     * Everything else is comparing the content or direct metadata of
+     * the file, but st_dev and st_ino represent the metadata of the
+     * filesystem which is (arguably) different.
+     */
+//    COMPARE_STAT (st_dev);
+//    COMPARE_STAT (st_ino);
     COMPARE_STAT (st_mode);
     COMPARE_STAT (st_nlink);
     COMPARE_STAT (st_uid);
